@@ -1,5 +1,6 @@
 import django
 from django.conf import settings
+from django.core.exceptions import ImproperlyConfigured
 
 if django.VERSION[0] >= 3 and django.VERSION[1] >= 1:
     # Django >= 3.1
@@ -11,7 +12,12 @@ else:
     else:
         from django_jsonform.models.compat import JSONField as DjangoJSONField
 
-from django.contrib.postgres.fields import ArrayField as DjangoArrayField
+try:
+    from django.contrib.postgres.fields import ArrayField as DjangoArrayField
+except ImportError:
+    class DjangoArrayField:
+        mock_field = True
+
 from django_jsonform.forms.fields import JSONFormField
 from django_jsonform.forms.fields import ArrayFormField
 
@@ -32,6 +38,9 @@ class JSONField(DjangoJSONField):
 
 class ArrayField(DjangoArrayField):
     def __init__(self, *args, **kwargs):
+        if hasattr(DjangoArrayField, 'mock_field'):
+            raise ImproperlyConfigured('ArrayField requires psycopg2 to be installed.')
+
         self.nested = kwargs.pop('nested', False)
         super().__init__(*args, **kwargs)
 
